==> brlcad-7.22.0.tar.bz2: brlcad-7.22.0/src/conv/step/ApplicationContextElement.h <==
/*                 ApplicationContextElement.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2012 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file step/ApplicationContextElement.h
 *
 * Class definition used to convert STEP "ApplicationContextElement" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef APPLICATION_CONTEXT_ELEMENT_H_
#define APPLICATION_CONTEXT_ELEMENT_H_

#include "STEPEntity.h"

#include "sdai.h"

// forward declaration of class
class ON_Brep;
class ApplicationContext;

class ApplicationContextElement: virtual public STEPEntity {
private:
    static string entityname;

protected:
    string name;
    ApplicationContext *frame_of_reference;

public:
    ApplicationContextElement();
    virtual ~ApplicationContextElement();
    ApplicationContextElement(STEPWrapper *sw, int step_id);
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual bool LoadONBrep(ON_Brep *brep);
    string ClassName();
    string Name();
    string Description();
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* APPLICATION_CONTEXT_ELEMENT_H_ */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */

==> brlcad-7.24.0.tar.bz2: brlcad-7.24.0/src/conv/step/ApplicationContextElement.h <==
/*                 ApplicationContextElement.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2013 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file step/ApplicationContextElement.h
 *
 * Class definition used to convert STEP "ApplicationContextElement" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef APPLICATION_CONTEXT_ELEMENT_H_
#define APPLICATION_CONTEXT_ELEMENT_H_

#include "STEPEntity.h"

#include "sdai.h"

// forward declaration of class
class ON_Brep;
class ApplicationContext;

class ApplicationContextElement: virtual public STEPEntity
{
private:
    static string entityname;
    static EntityInstanceFunc GetInstance;

protected:
    string name;
    ApplicationContext *frame_of_reference;

public:
    ApplicationContextElement();
    virtual ~ApplicationContextElement();
    ApplicationContextElement(STEPWrapper *sw, int step_id);
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual bool LoadONBrep(ON_Brep *brep);
    string ClassName();
    string Name();
    string Description();
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* APPLICATION_CONTEXT_ELEMENT_H_ */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */
